# cs107-FinalProject

[![Build Status](https://app.travis-ci.com/cs107-undefined/cs107-FinalProject.svg?branch=final_milestone)](https://app.travis-ci.com/cs107-undefined/cs107-FinalProject)

[![codecov](https://codecov.io/gh/cs107-undefined/cs107-FinalProject/branch/final_milestone/graph/badge.svg?token=MWEZONI94C)](https://codecov.io/gh/cs107-undefined/cs107-FinalProject)

[![Documentation Status](https://readthedocs.org/projects/cs107-undefined/badge/?version=latest)](https://cs107-undefined.readthedocs.io/en/latest/?badge=latest)

[**DOCUMENTATION**](https://cs107-undefined.readthedocs.io/en/latest/)


**Group Number:**

Group 1

**Group Members:**

_Xinran Tang xinran_tang@g.harvard.edu_

_Renhao Luo renhao_luo@hms.harvard.edu_

_Chelse Swoopes cswoopes@g.harvard.edu_

_Shijia Zhang shijiazhang@hms.harvard.edu_
